@@ -25,21 +25,36 @@ class SignalUserTemplate(object):
     def __hash__(self):
         return id(self)
 
-
     @property
     def unwrap(self):
         return self.wrapped_signal_
 
-
     @property
     def name(self):
         return self.wrapped_signal_.name
 
+    @property
+    def properties(self):
+        return self.wrapped_signal_.properties
+
+    def set_properties(self, p):
+        self.wrapped_signal_.set_properties(p)
+        return self
+
+    def set_datatype(self, datatype):
+        # call setDatatype_nonotitication to prevent the (untested) automatic update of the datatypes
+        self.wrapped_signal_.setDatatype_nonotitication(datatype)
+        return self
 
     def set_name(self, name):
         self.wrapped_signal_.set_name(name)
         return self
 
+    def set_name_raw(self, name):
+        self.wrapped_signal_.set_name_raw(name)
+        return self
+
+
     def extendName(self, name):
         self.wrapped_signal_.set_name( self.wrapped_signal_.name + name )
         return self
@@ -54,16 +69,16 @@ class SignalUserTemplate(object):
     # operator overloads
     #
     def __add__(self, other): 
-        return wrap_signal( block_prototypes.Operator1( dy.get_simulation_context(), inputSignals=[ self.unwrap, other.unwrap ], operator='+').outputSignals )
+        return wrap_signal( block_prototypes.Operator1( dy.get_simulation_context(), inputSignals=[ self.unwrap, other.unwrap ], operator='+').outputs[0] )
 
     def __sub__(self, other): 
-        return wrap_signal( block_prototypes.Operator1( dy.get_simulation_context(), inputSignals=[ self.unwrap, other.unwrap ], operator='-').outputSignals )
+        return wrap_signal( block_prototypes.Operator1( dy.get_simulation_context(), inputSignals=[ self.unwrap, other.unwrap ], operator='-').outputs[0] )
 
     def __mul__(self, other): 
-        return wrap_signal( block_prototypes.Operator1( dy.get_simulation_context(), inputSignals=[ self.unwrap, other.unwrap ], operator='*').outputSignals )
+        return wrap_signal( block_prototypes.Operator1( dy.get_simulation_context(), inputSignals=[ self.unwrap, other.unwrap ], operator='*').outputs[0] )
 
     def __truediv__(self, other): 
-        return wrap_signal( block_prototypes.Operator1( dy.get_simulation_context(), inputSignals=[ self.unwrap, other.unwrap ], operator='/').outputSignals )
+        return wrap_signal( block_prototypes.Operator1( dy.get_simulation_context(), inputSignals=[ self.unwrap, other.unwrap ], operator='/').outputs[0] )
 
     # comparison operators
     def __le__(self, other):
@@ -119,7 +134,9 @@ class SignalUser(SignalUserTemplate):
 
 
 
-
+#
+# TODO: is this still needed?
+#
 class SubsystemOutputLinkUser(SignalUser):
     """
         A signal that serves as a placeholder for a subsystem output to be used in the embedding
